## Checklist

- [ ] I have included information about relevant versions
- [ ] I have verified that the issue persists when using the `master` branch of Mode.

## Steps to reproduce

Tell us what you did to cause something to happen.

## Expected behavior

Tell us what you expected to happen.

## Actual behavior

Tell us what happened instead.

## Full traceback

```pytb
Paste the full traceback (if there is any)
```

# Versions

* Python version
* Mode version
* Operating system
